@@ -17,18 +17,20 @@ int main(int argc, char **argv)
     }
 
     void try(void) {
+	int qbits, rbits;
+
 	if (find_mnt6_curve(L, D, 500)) {
 	    for (; i<L->count; i++) {
-		printf("Curve %d-", D);
 		cm = L->item[i];
-		mpz_out_str(stdout, 0, cm->q);
-		printf(":\n%d-bit q\n", mpz_sizeinbase(cm->q, 2));
-		printf("%d-bit r\n", mpz_sizeinbase(cm->r, 2));
+		qbits = mpz_sizeinbase(cm->q, 2);
+		rbits = mpz_sizeinbase(cm->r, 2);
+		printf("%d, %d, %d\n", D, qbits, rbits);
 		fflush(stdout);
 	    }
 	}
     }
 
+    printf("D, bits in q, bits in r\n");
     while (D < 100000000) {
 	try();
 	D++;
